import {
  select,
  csv,
  scalePoint,
  scaleLinear,
  max,
  axisLeft,
  axisBottom,
  line,
} from 'd3';

// Rendering svg tag from HTML
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Creating Line graph
const render = (data) => {
  const title = 'Monthly sales in 2022';

  const xValue = (d) => d.Month; // Display months on x axis
  const xAxisLabel = 'Month';

  const yValue = (d) => d.Sales; // Display sales value on y axis
  const yAxisLabel = 'Sales (USD 000)';

  const margin = {
    top: 60,
    right: 40,
    bottom: 88,
    left: 150,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Create X scale with month values
  const xScale = scalePoint()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.5);

  const xAxis = axisBottom(xScale);

  // Create Y scale with sales values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();

  // Styling Y axis label
  yAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', -90)
    .attr('x', -innerHeight / 3)
    .attr('fill', 'black') // Text color
    .attr('transform', `rotate(-90)`)
    .style('font-family', 'Arial') // Font family
    .style('font-size', '12px') // Font size
    .text(yAxisLabel);

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  // Styling X axis label
  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 70)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black') // Text color
    .style('font-family', 'Arial') // Font family
    .style('font-size', '12px') // Font size
    .text(xAxisLabel);

  // Creating line graph
  const lineGenerator = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  // Styling the line
  g.append('path')
    .attr('class', 'line_path')
    .attr('d', lineGenerator(data))
    .attr('stroke', 'purple') // Line color
    .attr('stroke-width', 3) // Line width
    .attr('fill', 'none');

  // Styling the title
  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .style('font-family', 'Arial') // Font family
    .style('font-size', '16px') // Font size
    .text(title);
};

// Load your CSV data here
csv(
  'https://gist.githubusercontent.com/manogna-vanama/d5f66c6e5d1bf8c4ffdb1eed540811b5/raw/d351e3130166312554ec5637f5e5c378b07be319/salestrip.csv',
).then((data) => {
  data.forEach((d) => {
    d.Sales = +d['Sales (USD 000)']; // Convert Sales to number
  });
  render(data);
});
